import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import ObjectUtils from 'primereact/components/utils/ObjectUtils';

export class AutoCompletePanel extends Component {
	renderElement() {
		const {
			ariaLabel,
			ariaSelected,
			field,
			itemTemplate,
			listId,
			onItemClick,
			scrollHeight,
			suggestions,
		} = this.props;
		let items;

		if (suggestions) {
			items = suggestions.map((suggestion, index) => {
				const itemContent = itemTemplate
					? itemTemplate(suggestion)
					: field
					? ObjectUtils.resolveFieldData(suggestion, field)
					: suggestion;

				return (
					<li
						key={`${index}_item`}
						role="option"
						aria-selected={ariaSelected === suggestion}
						className="p-autocomplete-list-item"
						onClick={e => onItemClick(e, suggestion)}
						aria-label={`${ariaLabel} ${itemContent}`}
					>
						{itemContent}
					</li>
				);
			});
		}

		return (
			<div
				ref={el => (this.element = el)}
				className="p-autocomplete-panel p-input-overlay"
				style={{ maxHeight: scrollHeight }}
			>
				<ul
					className="p-autocomplete-items p-autocomplete-list p-component p-reset"
					role="listbox"
					id={listId}
				>
					{items}
				</ul>
			</div>
		);
	}

	render() {
		const { appendTo } = this.props;
		const element = this.renderElement();

		if (appendTo) {
			return ReactDOM.createPortal(element, appendTo);
		} else {
			return element;
		}
	}
}
AutoCompletePanel.defaultProps = {
	suggestions: null,
	field: null,
	appendTo: null,
	itemTemplate: null,
	onItemClick: null,
	scrollHeight: '200px',
	listId: null,
	ariaSelected: null,
};

AutoCompletePanel.propTypes = {
	appendTo: PropTypes.any,
	ariaLabel: PropTypes.string,
	ariaSelected: PropTypes.any,
	field: PropTypes.string,
	itemTemplate: PropTypes.func,
	listId: PropTypes.any,
	onItemClick: PropTypes.func,
	scrollHeight: PropTypes.string,
	suggestions: PropTypes.array,
};

export default AutoCompletePanel;
